@@ -1,6 +1,6 @@
 # ABSTRACT: ArangoDB Collection object
 package Arango::Tango::Collection;
-$Arango::Tango::Collection::VERSION = '0.018';
+$Arango::Tango::Collection::VERSION = '0.019';
 use warnings;
 use strict;
 
@@ -15,6 +15,7 @@ BEGIN {
             inject_properties => ['database', 'name'],
             signature => ['key'],
             ## FIXME - Header parameters still not supported
+            ## FIXME: missing schema options
         },
 
         document => {
@@ -113,9 +114,15 @@ sub bulk_import {
     })
 }
 
-sub document_paths {
+sub document_paths {              ## FIXME: try to get larger cursors whenever possible
     my ($self) = @_;
-    return $self->{arango}->_api( all_keys => { database => $self->{database}, collection => $self->{name}, type => "path"})->{result}
+    my $paths = [];
+    my $query = qq!FOR doc IN $self->{name} RETURN CONCAT("/_db/", CURRENT_DATABASE(), "/_api/document/", doc._id)!;
+    my $cursor = $self->cursor($query);
+    while(my $row = $cursor->next) {
+        push @$paths, @$row;
+    }
+    return $paths;
 }
 
 sub create_document {
@@ -145,6 +152,10 @@ sub set_access_level {
     return $self->{arango}->set_access_level($username, $grant, $self->{database}, $self->{name});
 }
 
+sub cursor {
+    my ($self, $aql, %opts) = @_;
+    return Arango::Tango::Cursor->_new(arango => $self->{arango}, database => $self->{database}, query => $aql, %opts);
+}
 
 1;
 
@@ -160,7 +171,7 @@ Arango::Tango::Collection - ArangoDB Collection object
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 USAGE
 
@@ -314,6 +325,14 @@ Clears the collection access level for a specific user.
 
 Imports a group of documents in a single call.
 
+=head2 C<cursor>
+
+   my $cursor = $collection->cursor( $aql_query, %opt );
+
+Performs AQL queries, returning a cursor. An optional hash of
+options can be supplied. Supported hashes corresponds to the different attributes
+available in the ArangoDB REST API (L<https://docs.arangodb.com/3.4/HTTP/AqlQueryCursor/AccessingCursors.html>).
+
 =head1 AUTHOR
 
 Alberto Simões <ambs@cpan.org>
